@@ -189,13 +189,13 @@ bool Backend::query_execute(const Glib::RefPtr<Gnome::Gda::Connection>& connecti
 #endif
 }
 
-#ifndef GLOM_ENABLE_CLIENT_ONLY
 bool Backend::add_column(const Glib::RefPtr<Gnome::Gda::Connection>& connection, const Glib::ustring& table_name, const sharedptr<const Field>& field, std::auto_ptr<Glib::Error>& error)
 {
   Glib::RefPtr<Gnome::Gda::ServerProvider> provider = connection->get_provider();
   Glib::RefPtr<Gnome::Gda::ServerOperation> operation = create_server_operation(provider, connection, Gnome::Gda::SERVER_OPERATION_ADD_COLUMN, error);
   if(!operation) return false;
 
+  //TODO: Quote table_name and field_name?
   if(!set_server_operation_value(operation, "/COLUMN_DEF_P/TABLE_NAME", table_name, error))
     return false;
 
@@ -224,6 +224,7 @@ bool Backend::drop_column(const Glib::RefPtr<Gnome::Gda::Connection>& connection
   if(!operation)
     return false;
 
+  //TODO: Quote table name and column name?
   if(!set_server_operation_value(operation, "/COLUMN_DESC_P/TABLE_NAME", table_name, error))
     return false;
 
@@ -293,7 +294,6 @@ bool Backend::change_columns(const Glib::RefPtr<Gnome::Gda::Connection>& connect
 
   return true;
 }
-#endif // !GLOM_ENABLE_CLIENT_ONLY
 
 } // namespace ConnectionPoolBackends
 
