@@ -32,10 +32,11 @@
 #include <libglom/data_structure/glomconversions.h>
 #include <glom/glade_utils.h>
 #include <glom/mode_data/box_data_list_related.h>
-#include <glom/mode_data/dialog_choose_relationship.h>
+#include <glom/mode_design/layout/dialog_choose_relationship.h>
 #include <glom/utils_ui.h> //For bold_message()).
 #include <libglom/data_structure/layout/layoutitem_placeholder.h>
 #include <glom/signal_reemitter.h>
+
 #include <glibmm/i18n.h>
 
 namespace Glom
@@ -193,7 +194,12 @@ void FlowTableWithFields::add_layout_group_at_position(const sharedptr<LayoutGro
     Gtk::Alignment* alignment = Gtk::manage( new Gtk::Alignment ); //TODO_leak: This is possibly leaked, according to valgrind.
 
     if(!group->get_title().empty()) //Don't indent if it has no title, to allow use of groups just for positioning.
+    {
       alignment->set_padding(Glom::Utils::DEFAULT_SPACING_SMALL, 0, 6, 0); //Use left-padding of 6 even on Maemo because indentation is important.
+      #ifdef GLOM_ENABLE_MAEMO
+      std::cerr << "DEBUG: Unexpected group with title causing extra spacing on Maemo." << std::endl;
+      #endif
+    }
 
     alignment->show();
     frame->add(*alignment);
@@ -202,15 +208,20 @@ void FlowTableWithFields::add_layout_group_at_position(const sharedptr<LayoutGro
     add_view(flow_table); //Allow these sub-flowtables to access the document too.
     flow_table->set_table(m_table_name);
 
-    flow_table->set_columns_count(group->m_columns_count);
-    flow_table->set_padding(Utils::DEFAULT_SPACING_SMALL);
+    flow_table->set_columns_count(group->get_columns_count());
+    
+    //Use the parent table's padding:
+    flow_table->set_column_padding(get_column_padding());
+    flow_table->set_row_padding(get_row_padding());
     flow_table->show();
     
     Gtk::EventBox* event_box = Gtk::manage( new Gtk::EventBox() ); //TODO_Leak: Valgrind says this is possibly leaked.
     event_box->add(*flow_table);
     event_box->set_visible_window(false);
+#ifndef GLOM_ENABLE_CLIENT_ONLY
     event_box->signal_button_press_event().connect (sigc::mem_fun (*flow_table,
       &FlowTableWithFields::on_button_press_event));
+#endif      
     event_box->show();
     
     alignment->add(*event_box);
@@ -385,16 +396,19 @@ void FlowTableWithFields::add_layout_notebook_at_position(const sharedptr<Layout
         add_view(flow_table); //Allow these sub-flowtables to access the document too.
         flow_table->set_table(m_table_name);
 
-        flow_table->set_columns_count(group->m_columns_count);
-        flow_table->set_padding(Utils::DEFAULT_SPACING_SMALL);
+        flow_table->set_columns_count(group->get_columns_count());
+        flow_table->set_column_padding(get_column_padding());
+        flow_table->set_row_padding(get_row_padding());
         flow_table->show();
         
         // Put the new flowtable in an event box to catch events
         Gtk::EventBox* event_box = Gtk::manage( new Gtk::EventBox() ); //TODO_Leak: Valgrind says this is possibly leaked.
         event_box->add(*flow_table);
         event_box->set_visible_window(false);
+#ifndef GLOM_ENABLE_CLIENT_ONLY        
         event_box->signal_button_press_event().connect (sigc::mem_fun (*flow_table,
                                                                        &FlowTableWithFields::on_button_press_event));
+#endif                                                                       
         event_box->show();
         //This doesn't work (probably because we haven't implmented it in our custom container),
         //so we put the flowtable in an alignment and give that a border instead.
@@ -472,7 +486,8 @@ void FlowTableWithFields::add_group(const Glib::ustring& group_name, const Glib:
     FlowTableWithFields* flow_table = Gtk::manage( new FlowTableWithFields() );
 
     flow_table->set_columns_count(1);
-    flow_table->set_padding(Utils::DEFAULT_SPACING_SMALL);
+    flow_table->set_column_padding(get_column_padding());
+    flow_table->set_row_padding(get_row_padding());
     flow_table->show();
     alignment->add(*flow_table);
 
@@ -647,7 +662,7 @@ void FlowTableWithFields::add_placeholder_at_position(const sharedptr<LayoutItem
   m_placeholder->set(Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER);
   m_placeholder->show();
 
-  PlaceholderGlom* preview = Gtk::manage (new PlaceholderGlom);
+  PlaceholderGlom* preview = Gtk::manage(new PlaceholderGlom);
   preview->show();
 
   m_placeholder->add(*preview);
@@ -1202,6 +1217,42 @@ void FlowTableWithFields::on_flowtable_requested_related_details(const Glib::ust
 }
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
+
+void FlowTableWithFields::on_dnd_add_layout_item_by_type(int item_type_num, Gtk::Widget* above_widget)
+{
+  LayoutWidgetBase::enumType item_type = static_cast<LayoutWidgetBase::enumType>(item_type_num);
+  LayoutWidgetBase* above = dynamic_cast<LayoutWidgetBase*>(above_widget);
+  if(!above)
+    return;
+
+  switch(item_type)
+  {
+    case LayoutWidgetBase::TYPE_FIELD:
+      on_dnd_add_layout_item_field(above);
+      break;
+    case LayoutWidgetBase::TYPE_BUTTON:
+      on_dnd_add_layout_item_button(above);
+      break;
+    case LayoutWidgetBase::TYPE_TEXT:
+      on_dnd_add_layout_item_text(above);
+      break;
+    case LayoutWidgetBase::TYPE_IMAGE:
+      on_dnd_add_layout_item_image(above);
+      break;
+    case LayoutWidgetBase::TYPE_GROUP:
+      on_dnd_add_layout_group(above);
+      break;
+    case LayoutWidgetBase::TYPE_NOTEBOOK:
+      on_dnd_add_layout_notebook(above);
+      break;
+    case LayoutWidgetBase::TYPE_PORTAL:
+      on_dnd_add_layout_portal(above);
+      break;
+    default:
+      std::cerr << "FlowTableWithFields::on_dnd_add_layout_item(): Unknown drop type: " << item_type << std::endl;
+   }
+}
+
 void FlowTableWithFields::on_dnd_add_layout_item_field(LayoutWidgetBase* above)
 {
   //Ask the user to choose the layout item
@@ -1286,7 +1337,7 @@ void FlowTableWithFields::on_dnd_add_layout_item_text(LayoutWidgetBase* above)
   textobject->set_text(_("New Text"));
   sharedptr<LayoutItem> layout_item = sharedptr<LayoutItem>::cast_dynamic(textobject);
 
-  dnd_add_to_layout_group (layout_item, above);
+  dnd_add_to_layout_group(layout_item, above);
   //Tell the parent to tell the document to save the layout
 
   signal_layout_changed().emit();
@@ -1298,7 +1349,7 @@ void FlowTableWithFields::on_dnd_add_layout_item_image(LayoutWidgetBase* above)
   sharedptr<LayoutItem_Image> image_object = sharedptr<LayoutItem_Image>::create();
   sharedptr<LayoutItem> layout_item = sharedptr<LayoutItem>::cast_dynamic(image_object);
 
-  dnd_add_to_layout_group (layout_item, above);
+  dnd_add_to_layout_group(layout_item, above);
   //Tell the parent to tell the document to save the layout
 
   signal_layout_changed().emit();
@@ -1312,8 +1363,12 @@ void FlowTableWithFields::on_dnd_add_layout_item(LayoutWidgetBase* above, const
   // signal_layout_changed().emit();
 }
 
-void FlowTableWithFields::on_dnd_add_placeholder(LayoutWidgetBase* above)
+void FlowTableWithFields::on_dnd_add_placeholder(Gtk::Widget* above_widget)
 {
+  LayoutWidgetBase* above = dynamic_cast<LayoutWidgetBase*>(above_widget);
+  if(!above)
+    return;
+
   if(m_placeholder)
   {
     if(dynamic_cast<Glom::PlaceholderGlom*>(above))
@@ -1327,6 +1382,7 @@ void FlowTableWithFields::on_dnd_add_placeholder(LayoutWidgetBase* above)
   sharedptr<LayoutItem_Placeholder> placeholder_field(new LayoutItem_Placeholder);
   sharedptr<LayoutItem> item = sharedptr<LayoutItem>::cast_dynamic(placeholder_field);  
   add_layout_item_at_position(placeholder_field, cur_widget);
+
   dnd_add_to_layout_group(item, above, true /* ignore error*/);
 }
 
@@ -1340,7 +1396,7 @@ void FlowTableWithFields::on_dnd_remove_placeholder()
     { 
       LayoutGroup::type_list_items items = layout_group->get_items();
       for (LayoutGroup::type_list_items::iterator item = items.begin();
-           item != items.end(); item++)
+           item != items.end(); ++item)
       {
         sharedptr<LayoutItem_Placeholder> placeholder = 
           sharedptr<LayoutItem_Placeholder>::cast_dynamic(*item);
@@ -1360,7 +1416,8 @@ void FlowTableWithFields::on_dnd_remove_placeholder()
 
 void FlowTableWithFields::dnd_notify_failed_drop()
 {
-  // TODO: Avoid this error message
+  // TODO: Avoid this error message, maybe by adding a group.
+  // TODO: At least avoid losing the dragged item.
   Gtk::MessageDialog dialog(_("You cannot drop anything here. Try to add a group first"),
                       false, Gtk::MESSAGE_ERROR);
   dialog.run();
@@ -1402,7 +1459,7 @@ void FlowTableWithFields::on_menu_properties_activate()
       if(response == Gtk::RESPONSE_OK)
       {
         sharedptr<LayoutGroup> group = get_layout_group();
-        group->m_columns_count = dialog->get_columns_count();
+        group->set_columns_count( dialog->get_columns_count() );
         group->set_title(dialog->get_title());
         signal_layout_changed().emit();
       }
@@ -1497,6 +1554,26 @@ sharedptr<LayoutItem_Portal> FlowTableWithFields::get_portal_relationship()
   }
   return sharedptr<LayoutItem_Portal>();
 }
+
+void FlowTableWithFields::set_child_widget_dnd_in_progress(Gtk::Widget* child, bool in_progress)
+{
+  //To be reimplemented by derived classes.
+  LayoutWidgetBase* base = dynamic_cast<LayoutWidgetBase*>(child);
+  if(!child)
+    return;
+
+  base->set_dnd_in_progress(in_progress); 
+}
+
+bool FlowTableWithFields::get_child_widget_dnd_in_progress(Gtk::Widget* child) const
+{
+  LayoutWidgetBase* base = dynamic_cast<LayoutWidgetBase*>(child);
+  if(!base)
+    return false;
+  else
+    return base->get_dnd_in_progress();
+}
+
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
 } //namespace Glom
