@@ -497,7 +497,7 @@ bool Window_PrintLayout_Edit::init_db_details(const Glib::ustring& table_name)
   if(table_title.empty())
     table_label = table_name;
   else
-    table_label = table_title + " (" + table_name + ")";
+    table_label = table_title + " (" + table_name + ')';
 
   if(m_label_table)
     m_label_table->set_text(table_label);
@@ -640,7 +640,7 @@ void Window_PrintLayout_Edit::setup_context_menu()
   #else
   std::auto_ptr<Glib::Error> error;
   m_context_menu_uimanager->add_ui_from_string(ui_info, error);
-  if(error.get() != NULL)
+  if(error.get())
   {
     std::cerr << "building menus failed: " << error->what();
   }
