@@ -19,33 +19,50 @@
  */
 
 #include "db_adddel_withbuttons.h"
-//#include <libgnome/gnome-i18n.h>
+#include <glom/utils_ui.h>
 
 namespace Glom
 {
 
 DbAddDel_WithButtons::DbAddDel_WithButtons()
 : m_HBox(false, Utils::DEFAULT_SPACING_SMALL),
-  m_Button_Add(Gtk::Stock::ADD),
+#ifndef GLOM_ENABLE_MAEMO
   m_Button_Del(Gtk::Stock::DELETE),
-  m_Button_Edit(Gtk::Stock::OPEN)
+  m_Button_Edit(Gtk::Stock::OPEN),
+  m_Button_Add(Gtk::Stock::ADD)
+#else
+  m_Button_Add(Gtk::Hildon::SIZE_FINGER_HEIGHT, Hildon::BUTTON_ARRANGEMENT_HORIZONTAL)
+#endif
 {
   m_HBox.set_spacing(Utils::DEFAULT_SPACING_SMALL);
-  //m_Button_Add.set_border_width(Utils::DEFAULT_SPACING_SMALL);
-  //m_Button_Del.set_border_width(Utils::DEFAULT_SPACING_SMALL);
-  //m_Button_Edit.set_border_width(Utils::DEFAULT_SPACING_SMALL);
 
   setup_buttons();
   pack_start(m_HBox, Gtk::PACK_SHRINK);
 
   //Link buttons to handlers:
+    
+  #ifndef GLOM_ENABLE_MAEMO
   m_Button_Add.signal_clicked().connect(sigc::mem_fun(*this, &DbAddDel_WithButtons::on_button_add));
+  m_HBox.pack_end(m_Button_Add, Gtk::PACK_SHRINK);
+ 
   m_Button_Del.signal_clicked().connect(sigc::mem_fun(*this, &DbAddDel_WithButtons::on_button_del));
   m_Button_Edit.signal_clicked().connect(sigc::mem_fun(*this, &DbAddDel_WithButtons::on_button_edit));
 
   m_HBox.pack_end(m_Button_Edit, Gtk::PACK_SHRINK);
   m_HBox.pack_end(m_Button_Del, Gtk::PACK_SHRINK);
-  m_HBox.pack_end(m_Button_Add, Gtk::PACK_SHRINK);
+  #else
+  m_HBox.hide();
+  #endif //GLOM_ENABLE_MAEMO
+
+  #ifdef GLOM_ENABLE_MAEMO
+  //Use smaller icon-only buttons for these infrequently-clicked buttons,
+  //to save screen space.
+  
+  //Note that icons of size Gtk::ICON_SIZE_MENU are smaller, 
+  //but it seems impossible to have Hildon::Buttons smaller than Gtk::Hildon::SIZE_FINGER_HEIGHT.
+  Gtk::Image* image = Gtk::manage(new Gtk::Image(Gtk::Stock::ADD, Gtk::ICON_SIZE_SMALL_TOOLBAR));
+  m_Button_Add.set_image(*image);
+  #endif //GLOM_ENABLE_MAEMO
 
   setup_buttons();
 }
@@ -54,6 +71,7 @@ DbAddDel_WithButtons::~DbAddDel_WithButtons()
 {
 }
 
+#ifndef GLOM_ENABLE_MAEMO
 void DbAddDel_WithButtons::on_button_add()
 {
   on_MenuPopup_activate_Add();
@@ -66,8 +84,9 @@ void DbAddDel_WithButtons::on_button_del()
 
 void DbAddDel_WithButtons::on_button_edit()
 {
-  on_MenuPopup_activate_Edit();
+  do_user_requested_edit();
 }
+#endif //GLOM_ENABLE_MAEMO
 
 void DbAddDel_WithButtons::set_allow_add(bool val)
 {
@@ -99,21 +118,24 @@ void DbAddDel_WithButtons::setup_buttons()
   const bool allow_del = get_allow_user_actions() && m_allow_delete;
   const bool allow_add = get_allow_user_actions() && m_allow_add;
  
-  m_Button_Edit.show();
-  m_Button_Del.show();
   m_Button_Add.show();
-  
-  m_Button_Edit.set_property("visible", allow_edit);
-  m_Button_Del.set_property("visible", allow_del);
   m_Button_Add.set_property("visible", allow_add);
+ 
+   
+  #ifndef GLOM_ENABLE_MAEMO
+  m_Button_Edit.show();
+  m_Button_Edit.set_property("visible", allow_edit);
   
   if(!m_open_button_title.empty())
     m_Button_Edit.set_label(m_open_button_title);
+ 
+  m_Button_Del.show();
+  m_Button_Del.set_property("visible", allow_del);
+  #endif //GLOM_ENABLE_MAEMO
   
   m_HBox.show();
 }
 
-#ifdef GLIBMM_VFUNCS_ENABLED
 // TODO_maemo: Why is this show_all_vfunc, and not on_show()? Where is the
 // difference? If this was on_show we could just connect to signal_show()
 // when vfuncs and/or default signal handlers are not available.
@@ -125,7 +147,6 @@ void DbAddDel_WithButtons::show_all_vfunc()
   //Hide some stuff:
   setup_buttons();
 }
-#endif
 
 void DbAddDel_WithButtons::set_allow_view_details(bool val)
 {
