@@ -24,6 +24,7 @@
 #include <gdk/gdktypes.h>
 #include <iostream>
 #include <gdkmm/window.h>
+#include <glom/utils_ui.h>
 #include <gtk/gtk.h>
 
 
@@ -142,7 +143,7 @@ gboolean FlowTable::glom_expose_event_impl(GtkWidget* widget, GdkEventExpose* ev
   else if(GTK_WIDGET_CLASS(parent_class)->expose_event)
     return GTK_WIDGET_CLASS(parent_class)->expose_event(widget, event);
   else
-    return FALSE;
+    return false;
 }
 #endif // !GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
 } //namespace Glom
@@ -201,7 +202,8 @@ FlowTable::FlowTable()
   Glib::ObjectBase("Glom_FlowTable"),
 #endif // ! !defined(GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED)
   m_columns_count(1),
-  m_padding(0),
+  m_column_padding(Utils::DEFAULT_SPACING_SMALL), //A sane default.
+  m_row_padding(Utils::DEFAULT_SPACING_SMALL), //A sane default.
   m_design_mode(false)
 {
 #if !defined(GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED)
@@ -307,7 +309,7 @@ void FlowTable::insert_before(FlowTableItem& item, Gtk::Widget& before)
 {
   bool found = false;
   std::vector<FlowTableItem>::iterator pos;
-  for(pos = m_children.begin(); pos != m_children.end(); pos++)
+  for(pos = m_children.begin(); pos != m_children.end(); ++pos)
   {
     FlowTableItem* item = &(*pos);
     if(item->m_first)
@@ -441,7 +443,7 @@ int FlowTable::get_column_height(guint start_widget, guint widget_count, int& to
   for(i = start_widget; i < (start_widget+widget_count);  ++i)
   {
     const FlowTableItem& item = m_children[i];
-    int item_height = get_item_requested_height(item);
+    const int item_height = get_item_requested_height(item);
 
     int item_width_first = 0;
     int item_width_second = 0;
@@ -452,15 +454,15 @@ int FlowTable::get_column_height(guint start_widget, guint widget_count, int& to
     //Add the padding if it's not the first widget, and if one is visible:
     if( (i != start_widget) && item_height)
     {
-      column_height += m_padding;
+      column_height += m_row_padding;
     }
 
     if(item_height) //If one was visible.
     {
       if(child_is_visible(item.m_second))
       {
-        column_width_first =MAX(column_width_first, item_width_first);
-        column_width_second =MAX(column_width_second, item_width_second);
+        column_width_first = MAX(column_width_first, item_width_first);
+        column_width_second = MAX(column_width_second, item_width_second);
       }
       else
       {
@@ -478,7 +480,7 @@ int FlowTable::get_column_height(guint start_widget, guint widget_count, int& to
    total_width = MAX(total_width, column_width_singles);
 
    if( (column_width_first > 0) && (column_width_second > 0) ) //Add padding if necessary.
-     total_width += m_padding;
+     total_width += m_column_padding;
 
   return column_height;
 }  
@@ -521,7 +523,7 @@ int FlowTable::get_minimum_column_height(guint start_widget, guint columns_count
       if( others_column_start_widget  < m_children.size())
       {
         minimum_column_height_nextcolumns = get_minimum_column_height(others_column_start_widget, columns_count - 1, others_column_width);
-        others_column_width += m_padding; //Add the padding between the previous column and this one.
+        others_column_width += m_column_padding; //Add the padding between the previous column and this one.
 
         minimum_column_height_sofar = MAX(first_column_height, minimum_column_height_nextcolumns);
       }
@@ -625,7 +627,7 @@ void FlowTable::get_item_max_width_requested(guint start, guint height, guint& f
     guint padding_above = 0;
     //Add padding above the item, if it is after another one.
     if( first_item_added && (child_is_visible(first) || child_is_visible(second)) )
-       padding_above += m_padding;
+       padding_above += m_row_padding;
 
     guint item_first_width = 0;
     guint singles_width = 0;
@@ -708,10 +710,10 @@ void FlowTable::on_size_allocate(Gtk::Allocation& allocation)
 
   int column_x_start_second = column_x_start + first_max_width;
   if(first_max_width > 0) //Add padding between first and second sub sets of items, if there is a first set.
-    column_x_start_second += m_padding;
+    column_x_start_second += m_column_padding;
 
   //Used for drawing horizontal lines:
-  guint column_max_width = MAX(first_max_width + m_padding + second_max_width, singles_max_width);
+  guint column_max_width = MAX(first_max_width + m_column_padding + second_max_width, singles_max_width);
   //Use the whole remaining width if there is no column after this:
   if(is_last_column)
   {
@@ -736,10 +738,10 @@ void FlowTable::on_size_allocate(Gtk::Allocation& allocation)
       int column_x_start_plus_singles = column_x_start + singles_max_width;
       column_x_start = column_x_start_second + second_max_width;
       column_x_start = MAX(column_x_start, column_x_start_plus_singles); //Maybe the single items take up even more width.
-      column_x_start += m_padding;
+      column_x_start += m_column_padding;
 
       //Draw vertical line to separate the columns, in the middle of the padding:
-      const int line_x = column_x_start - (m_padding / 2);
+      const int line_x = column_x_start - (m_column_padding / 2);
       const int line_height = allocation.get_height();
       m_lines_vertical.push_back( type_line( Gdk::Point(line_x, allocation.get_y()), Gdk::Point(line_x, allocation.get_y() + line_height) ) );
 
@@ -754,10 +756,10 @@ void FlowTable::on_size_allocate(Gtk::Allocation& allocation)
 
         column_x_start_second = column_x_start + first_max_width;
         if(first_max_width > 0) //Add padding between first and second sub sets of items, if there is a first set.
-          column_x_start_second += m_padding;
+          column_x_start_second += m_column_padding;
 
         //Used for drawing horizontal lines:
-        column_max_width = MAX(first_max_width + m_padding + second_max_width, singles_max_width);
+        column_max_width = MAX(first_max_width + m_column_padding + second_max_width, singles_max_width);
 
         //Use the whole remaining width if there is no column after this:
         if(is_last_column)
@@ -794,7 +796,7 @@ void FlowTable::on_size_allocate(Gtk::Allocation& allocation)
           item.m_second_allocation = assign_child(second, column_x_start_second, column_child_y_start);
         else
         {
-          const int second_width_available = column_max_width - first_max_width - m_padding;
+          const int second_width_available = column_max_width - first_max_width - m_column_padding;
           item.m_second_allocation = assign_child(second, column_x_start_second, column_child_y_start, second_width_available, item_height);
         }
 
@@ -820,10 +822,10 @@ void FlowTable::on_size_allocate(Gtk::Allocation& allocation)
     {
       //Start the next child below this child, plus the padding
       column_child_y_start += item_height;
-      column_child_y_start += m_padding; //Ignored if this is the last item - we will just start a new column when we find that column_child_y_start is too much.
+      column_child_y_start += m_row_padding; //Ignored if this is the last item - we will just start a new column when we find that column_child_y_start is too much.
 
       //Add horizontal line in the middle of the padding:
-      const guint line_y = column_child_y_start - (m_padding / 2);
+      const guint line_y = column_child_y_start - (m_row_padding / 2);
       const guint line_width = column_max_width;
       m_lines_horizontal.push_back( type_line( Gdk::Point(column_x_start, line_y), Gdk::Point(column_x_start + line_width, line_y) ) );
     }
@@ -912,11 +914,24 @@ void FlowTable::forall(const ForallSlot& slot)
   gtk_container_forall(gobj(), &container_forall_callback, &slot_copy);
 }
 
-/** Sets the padding to put between the child widgets.
- */
-void FlowTable::set_padding(guint padding)
+void FlowTable::set_column_padding(guint padding)
 {
-  m_padding = padding; 
+  m_column_padding = padding; 
+}
+
+guint FlowTable::get_column_padding() const
+{
+  return m_column_padding;
+}
+
+void FlowTable::set_row_padding(guint padding)
+{
+  m_row_padding = padding; 
+}
+
+guint FlowTable::get_row_padding() const
+{
+  return m_row_padding;
 }
 
 bool FlowTable::child_is_visible(const Gtk::Widget* widget) const
@@ -1040,4 +1055,3 @@ bool FlowTable::on_expose_event(GdkEventExpose* event)
 
 } //namespace Glom
 
-
