@@ -39,7 +39,7 @@ protected:
   void setup_util_menu();
   Gtk::Menu* m_pPopupMenuUtils;
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-  virtual void on_menu_properties_activate() = 0;
+  virtual void on_menu_properties_activate();
 
   // This one is implemented here:
   virtual void on_menu_delete_activate();
