@@ -145,7 +145,7 @@ void Utils::show_help(const Glib::ustring& id)
     else
     {
       std::string uri = "ghelp:" + help_file;
-      if(pId) { uri += "?"; uri += pId; }
+      if(pId) { uri += '?'; uri += pId; }
 
       // g_app_info_launch_default_for_uri seems not to be wrapped by giomm
       if(!g_app_info_launch_default_for_uri(uri.c_str(), 0, &err))
@@ -340,7 +340,7 @@ static int get_width_for_text(Gtk::Widget& widget, const Glib::ustring& text)
 
 int Utils::get_suitable_field_width_for_widget(Gtk::Widget& widget, const sharedptr<const LayoutItem_Field>& field_layout, bool or_title)
 {
-  int result = 150;
+  int result = 150; //Suitable default.
 
   const Field::glom_field_type field_type = field_layout->get_glom_type();
 
@@ -394,7 +394,7 @@ int Utils::get_suitable_field_width_for_widget(Gtk::Widget& widget, const shared
   if(!example_text.empty())
   {
     //Get the width required for this string in the current font:
-    result += get_width_for_text(widget, example_text);
+    result = get_width_for_text(widget, example_text);
   }
 
   if(or_title)
